@@ -1,4 +1,6 @@
 import chevron
+import json
+import xmltodict
 from requests import JSONDecodeError
 from .authenticate import Authenticate
 from .attachments import parse_attachment_output
@@ -53,11 +55,14 @@ class Runner(Authenticate):
             file = parse_attachment_output(response, action_schema)
             if file:
                 output['file'] = file
-
-        try:
-            output['json_body'] = response.json()
-        except JSONDecodeError:
-            if 'file' not in output:
-                # Avoids the duplication of the file content in response_text
-                output['response_text'] = response.text
+        output_type = action_schema["meta"].get("outputType", "json")
+        if output_type == "xml":
+            output["json_body"] = xmltodict.parse(response.text)
+        else:
+            try:
+                output['json_body'] = response.json()
+            except JSONDecodeError:
+                if 'file' not in output:
+                    # Avoids the duplication of the file content in response_text
+                    output['response_text'] = response.text
         return output
